import gtk                 # needed to get colors and axcess to the widgets
import os                  # needed to get the paths
import hal                 # base hal class to react to hal signals
import hal_glib            # needed to make our own hal pins

CONFIGPATH = os.environ['CONFIG_DIR']
IMAGEDIR = os.path.join(CONFIGPATH, "IMAGES")

class HandlerClass:
    def __init__(self, halcomp,builder,useropts):

        self.halcomp = halcomp
        self.builder = builder
        
        # do we want to create our own hal pin?
        self._make_hal_pin()
        

        # set up a reference to an image object for true state of toggle
        self.image_toggle_true = gtk.Image()
        image = os.path.join(IMAGEDIR, 'machine_on.png')
        self.image_toggle_true.set_from_file(image)

        # set up a reference to an image object for false state of toggle
        self.image_toggle_false = gtk.Image()
        image = os.path.join(IMAGEDIR, 'machine_off.png')
        self.image_toggle_false.set_from_file(image)

        # set default image for button - this image doesn't change
        tbtn = self.builder.get_object('tbtn_led3')
        tbtn.set_image(self.image_toggle_false)
        
        # we want also different colors for the tbtn_move_z
        tbtn = self.builder.get_object('tbtn_move_z')
        tbtn.modify_bg(gtk.STATE_ACTIVE, gtk.gdk.color_parse("#FF0000"))
        tbtn.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#00FF00"))

        # and the push button btn_led2 should get a light blue when active
        # I selected the same color as the led has ;-)
        btn = self.builder.get_object('btn_led2')
        btn.modify_bg(gtk.STATE_ACTIVE, gtk.gdk.color_parse("#1DABFC"))
 
        # get the label hits to display the hits on it, set init value
        self.lbl_hits = self.builder.get_object('lbl_hits')
        self.lbl_hits.set_text("0")
        
    def on_btn_led2_clicked(self, widget):
        name = gtk.Buildable.get_name(widget)
        print("Button {0} has been clicked".format(name))
        value = int(self.lbl_hits.get_text())
        value += 1
        self.lbl_hits.set_text(str(value))
        self.halcomp['count-clicks-out'] = value

    def on_tbtn_led3_toggled(self, widget):
        name = gtk.Buildable.get_name(widget)
        print("Button {0} has been toggled".format(name))
        if widget.get_active():
            widget.set_image(self.image_toggle_true)
        else:
            widget.set_image(self.image_toggle_false)

    def on_pin_in_changed(self, pin):
        print("received a new value {0} from pin {1}".format(pin.name, pin.get()))

    def _make_hal_pin(self):
        print("Making hal pin")
        pin = self.halcomp.newpin('count-clicks-out', hal.HAL_S32, hal.HAL_OUT)

        pin = self.halcomp.newpin('pin-in', hal.HAL_S32, hal.HAL_IN)
        hal_glib.GPin(pin).connect('value_changed', self.on_pin_in_changed)


# boiler code
def get_handlers(halcomp,builder,useropts):
    return [HandlerClass(halcomp,builder,useropts)]
